==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/NetworkingAndContentDelivery/AwsDirectConnectGateway.md <==
# AwsDirectConnectGateway


```text
aws-20210730/Resource/NetworkingAndContentDelivery/AwsDirectConnectGateway
```

```text
include('aws-20210730/Resource/NetworkingAndContentDelivery/AwsDirectConnectGateway')
```



| Illustration | AwsDirectConnectGateway | AwsDirectConnectGatewayCard | AwsDirectConnectGatewayGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/NetworkingAndContentDelivery/AwsDirectConnectGateway.png) | ![illustration for AwsDirectConnectGateway](../../../aws-20210730/Resource/NetworkingAndContentDelivery/AwsDirectConnectGateway.Local.png) | ![illustration for AwsDirectConnectGatewayCard](../../../aws-20210730/Resource/NetworkingAndContentDelivery/AwsDirectConnectGatewayCard.Local.png) | ![illustration for AwsDirectConnectGatewayGroup](../../../aws-20210730/Resource/NetworkingAndContentDelivery/AwsDirectConnectGatewayGroup.Local.png) |




## AwsDirectConnectGateway

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsDirectConnectGateway
include('aws-20210730/Resource/NetworkingAndContentDelivery/AwsDirectConnectGateway')

' renders the element
AwsDirectConnectGateway('AwsDirectConnectGateway', 'Aws Direct Connect Gateway', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsDirectConnectGateway
include('aws-20210730/Resource/NetworkingAndContentDelivery/AwsDirectConnectGateway')

' renders the element
AwsDirectConnectGateway('AwsDirectConnectGateway', 'Aws Direct Connect Gateway', 'an optional tech label')
@enduml
```

## AwsDirectConnectGatewayCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsDirectConnectGatewayCard
include('aws-20210730/Resource/NetworkingAndContentDelivery/AwsDirectConnectGateway')

' renders the element
AwsDirectConnectGatewayCard('AwsDirectConnectGatewayCard', 'Aws Direct Connect Gateway Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsDirectConnectGatewayCard
include('aws-20210730/Resource/NetworkingAndContentDelivery/AwsDirectConnectGateway')

' renders the element
AwsDirectConnectGatewayCard('AwsDirectConnectGatewayCard', 'Aws Direct Connect Gateway Card', 'an optional description')
@enduml
```

## AwsDirectConnectGatewayGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsDirectConnectGatewayGroup
include('aws-20210730/Resource/NetworkingAndContentDelivery/AwsDirectConnectGateway')

' renders the element
AwsDirectConnectGatewayGroup('AwsDirectConnectGatewayGroup', 'Aws Direct Connect Gateway Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsDirectConnectGatewayGroup
include('aws-20210730/Resource/NetworkingAndContentDelivery/AwsDirectConnectGateway')

' renders the element
AwsDirectConnectGatewayGroup('AwsDirectConnectGatewayGroup', 'Aws Direct Connect Gateway Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-20210730/Resource/NetworkingAndContentDelivery/AwsDirectConnectGateway.md <==
# AwsDirectConnectGateway


```text
aws-20210730/Resource/NetworkingAndContentDelivery/AwsDirectConnectGateway
```

```text
include('aws-20210730/Resource/NetworkingAndContentDelivery/AwsDirectConnectGateway')
```



| Illustration | AwsDirectConnectGateway | AwsDirectConnectGatewayCard | AwsDirectConnectGatewayGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/NetworkingAndContentDelivery/AwsDirectConnectGateway.png) | ![illustration for AwsDirectConnectGateway](../../../aws-20210730/Resource/NetworkingAndContentDelivery/AwsDirectConnectGateway.Local.png) | ![illustration for AwsDirectConnectGatewayCard](../../../aws-20210730/Resource/NetworkingAndContentDelivery/AwsDirectConnectGatewayCard.Local.png) | ![illustration for AwsDirectConnectGatewayGroup](../../../aws-20210730/Resource/NetworkingAndContentDelivery/AwsDirectConnectGatewayGroup.Local.png) |




## AwsDirectConnectGateway

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsDirectConnectGateway
include('aws-20210730/Resource/NetworkingAndContentDelivery/AwsDirectConnectGateway')

' renders the element
AwsDirectConnectGateway('AwsDirectConnectGateway', 'Aws Direct Connect Gateway', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsDirectConnectGateway
include('aws-20210730/Resource/NetworkingAndContentDelivery/AwsDirectConnectGateway')

' renders the element
AwsDirectConnectGateway('AwsDirectConnectGateway', 'Aws Direct Connect Gateway', 'an optional tech label')
@enduml
```

## AwsDirectConnectGatewayCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsDirectConnectGatewayCard
include('aws-20210730/Resource/NetworkingAndContentDelivery/AwsDirectConnectGateway')

' renders the element
AwsDirectConnectGatewayCard('AwsDirectConnectGatewayCard', 'Aws Direct Connect Gateway Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsDirectConnectGatewayCard
include('aws-20210730/Resource/NetworkingAndContentDelivery/AwsDirectConnectGateway')

' renders the element
AwsDirectConnectGatewayCard('AwsDirectConnectGatewayCard', 'Aws Direct Connect Gateway Card', 'an optional description')
@enduml
```

## AwsDirectConnectGatewayGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsDirectConnectGatewayGroup
include('aws-20210730/Resource/NetworkingAndContentDelivery/AwsDirectConnectGateway')

' renders the element
AwsDirectConnectGatewayGroup('AwsDirectConnectGatewayGroup', 'Aws Direct Connect Gateway Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsDirectConnectGatewayGroup
include('aws-20210730/Resource/NetworkingAndContentDelivery/AwsDirectConnectGateway')

' renders the element
AwsDirectConnectGatewayGroup('AwsDirectConnectGatewayGroup', 'Aws Direct Connect Gateway Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
